@@ -13,16 +13,16 @@ def test_filter_bag_by_filter():
     Confirm a bag will properly filter.
     """
 
-    filtered_tiddlers = control.filter_tiddlers_from_bag(bagfour, 'select=title:TiddlerOne')
+    filtered_tiddlers = list(control.filter_tiddlers_from_bag(bagfour, 'select=title:TiddlerOne'))
 
     assert len(filtered_tiddlers) == 1
     assert filtered_tiddlers[0].title == 'TiddlerOne'
 
-    filtered_tiddlers = control.filter_tiddlers_from_bag(bagfour, 'select=tag:tagone')
+    filtered_tiddlers = list(control.filter_tiddlers_from_bag(bagfour, 'select=tag:tagone'))
     assert len(filtered_tiddlers) == 2
 
     filters, thing = parse_for_filters('select=tag:tagone;select=title:TiddlerThree')
-    filtered_tiddlers = control.filter_tiddlers_from_bag(bagfour, filters)
+    filtered_tiddlers = list(control.filter_tiddlers_from_bag(bagfour, filters))
     assert len(filtered_tiddlers) == 1
     assert filtered_tiddlers[0].title == 'TiddlerThree'
 
