@@ -3,8 +3,6 @@
 Test the creation and data handling of policies.
 """
 
-import sys
-sys.path.append('.')
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.policy import Policy, ForbiddenError, UserRequiredError, create_policy_check
 
@@ -111,3 +109,10 @@ def test_malformed_policy():
     policy = Policy()
     policy.read = None # set the policy to a bad form
     assert policy.allows(guest_info, 'read')
+
+def test_confirm_attributes():
+    """Confirm the class attributes of a policy."""
+    attributes = Policy.attributes
+    for name in ['read', 'write', 'create', 'delete', 'accept', 'manage', 'owner']:
+        assert name in attributes
+
