@@ -29,7 +29,7 @@ bad_string = """modifiXr: test@example.com
 created: 
 modiFied: 200803030303
 type: None
-tgs: foobar [[foo bar]]
+tags:foobar [[foo bar]]
 
 Hello, I'm the content.
 """
@@ -57,14 +57,12 @@ def test_generated_txt_string():
     assert '%s' % serializer == expected_string, \
             'serializer goes to string as expected_string'
 
-# For the time being there is no malformed tiddler, so no
-# TiddlerFormatError.
-# def test_bad_string_raises():
-#     serializer = Serializer('text')
-#     foobar = Tiddler('foobar')
-#     serializer.object = foobar
-# 
-#     py.test.raises(TiddlerFormatError, 'serializer.from_string(bad_string)')
+def test_bad_string_raises():
+    serializer = Serializer('text')
+    foobar = Tiddler('foobar')
+    serializer.object = foobar
+
+    py.test.raises(TiddlerFormatError, 'serializer.from_string(bad_string)')
 
 def test_generated_json_string():
     serializer = Serializer('json')
