@@ -21,7 +21,7 @@ def test_filter_by_text():
     bags_tiddlers = bag.list_tiddlers()
     assert len(bags_tiddlers) == 10
 
-    found_tiddlers = control.filter_tiddlers_from_bag(bag, 'select=text:tiddler 0')
+    found_tiddlers = list(control.filter_tiddlers_from_bag(bag, 'select=text:tiddler 0'))
     assert len(found_tiddlers) == 1
     assert found_tiddlers[0].title == 'tiddler0'
 
@@ -32,7 +32,7 @@ def test_filter_by_text_string():
     bags_tiddlers = bag.list_tiddlers()
     assert len(bags_tiddlers) == 10
 
-    found_tiddlers = control.filter_tiddlers_from_bag(bag, 'select=text:tiddler 0')
+    found_tiddlers = list(control.filter_tiddlers_from_bag(bag, 'select=text:tiddler 0'))
     assert len(found_tiddlers) == 1
     assert found_tiddlers[0].title == 'tiddler0'
 
@@ -43,5 +43,5 @@ def test_filter_by_text_string_negate():
     bags_tiddlers = bag.list_tiddlers()
     assert len(bags_tiddlers) == 10
 
-    found_tiddlers = control.filter_tiddlers_from_bag(bag, 'select=text:!tiddler 0')
+    found_tiddlers = list(control.filter_tiddlers_from_bag(bag, 'select=text:!tiddler 0'))
     assert len(found_tiddlers) == 9
