@@ -2,8 +2,6 @@
 Test GETting a tiddler revision list.
 """
 
-import sys
-sys.path.append('.')
 
 from wsgi_intercept import httplib2_intercept
 import wsgi_intercept
@@ -90,6 +88,12 @@ def test_get_tiddler_revision_4_fail():
             method='GET')
     assert response['status'] == '404'
 
+def test_get_tiddler_revision_nonint_fail():
+    http = httplib2.Http()
+    response, content = http.request('http://our_test_domain:8001/bags/bag1/tiddlers/TestOne/revisions/four',
+            method='GET')
+    assert response['status'] == '404'
+
 def test_get_tiddler_revision_list_404():
     """
     Get a 404 when the tiddler doesn't exist.
