@@ -113,10 +113,10 @@ the HTML output of the server. See
 tiddlyweb.web.wsgi.HTMLPresenter and tiddlyweb.serializations.html
 for the classes and ids used.
 
-wikitext_renderer -- The default module for rendering
+wikitext.default_renderer -- The default module for rendering
 tiddler.text to HTML when tiddler.type is None.
 
-wikitext_render_map -- A dictionary mapping tiddler.type
+wikitext.type_render_map -- A dictionary mapping tiddler.type
 MIME-TYPES to modules with a render() function for
 turning that content-type into HTML.
 """
@@ -199,8 +199,8 @@ DEFAULT_CONFIG = {
         'log_level': 'INFO',
         'log_file': './tiddlyweb.log',
         'css_uri': '',
-        'wikitext_renderer': 'raw',
-        'wikitext_render_map': {},
+        'wikitext.default_renderer': 'raw',
+        'wikitext.type_render_map': {},
         }
 
 def merge_config(global_config, additional_config):
