@@ -57,9 +57,17 @@ def determine_tiddler_bag_from_recipe(recipe, tiddler, environ=None):
             bag = Bag(name=bag)
         if store:
             bag = store.get(bag)
-        for candidate_tiddler in filter_tiddlers_from_bag(bag, filter_string):
-            if tiddler.title == candidate_tiddler.title:
-                return bag
+        # If there is a filter_string then we need to load the tiddlers off
+        # the store. If there's not, then we can just use the list that is
+        # already in the bag, saving a bit of time.
+        if filter_string:
+            for candidate_tiddler in filter_tiddlers_from_bag(bag, filter_string):
+                if tiddler.title == candidate_tiddler.title:
+                    return bag
+        else:
+            for candidate_tiddler in bag.gen_tiddlers():
+                if tiddler.title == candidate_tiddler.title:
+                    return bag
 
     raise NoBagError('no suitable bag for %s' % tiddler.title)
 
@@ -93,8 +101,7 @@ def get_tiddlers_from_bag(bag):
     Return the list of tiddlers that are in a bag.
     """
 
-    tiddlers = bag.list_tiddlers()
-    loaded_tiddlers = []
+    tiddlers = bag.gen_tiddlers()
     if bag.store:
         for tiddler in tiddlers:
             try:
@@ -102,9 +109,7 @@ def get_tiddlers_from_bag(bag):
             except TiddlerFormatError:
                 # XXX do more here?
                 pass
-            loaded_tiddlers.append(tiddler)
-
-    return loaded_tiddlers
+            yield tiddler
 
 
 def filter_tiddlers_from_bag(bag, filters):
@@ -121,7 +126,7 @@ def filter_tiddlers_from_bag(bag, filters):
     if store:
         return recursive_filter(filters, get_tiddlers_from_bag(bag))
     else:
-        return recursive_filter(filters, bag.list_tiddlers())
+        return recursive_filter(filters, bag.gen_tiddlers())
 
 
 def _recipe_template(environ):
