@@ -5,6 +5,11 @@ Miscellaneous utility functions for TiddlyWeb.
 import codecs
 import os
 
+try:
+    from hashlib import sha1
+except ImportError:
+    from sha import sha as sha1
+
 
 class LockError(IOError):
     """
@@ -13,6 +18,14 @@ class LockError(IOError):
     pass
 
 
+def sha(data=''):
+    """
+    Centralize creation of sha digests, to
+    manage deprecation of the sha module.
+    """
+    return sha1(data)
+
+
 def read_utf8_file(filename):
     """
     Read a utf-8 encoded file.
