@@ -17,11 +17,9 @@ def _challenger_url(environ, system):
     system.
     """
     default_redirect = '%s/' % environ['tiddlyweb.config']['server_prefix']
-    redirect = environ['tiddlyweb.query'].get('tiddlyweb_redirect', [default_redirect])[0]
-    if len(redirect):
-        redirect = '?tiddlyweb_redirect=%s' % urllib.quote(redirect, safe='')
-    else:
-        redirect = ''
+    redirect = (environ['tiddlyweb.query'].get('tiddlyweb_redirect',
+        [default_redirect])[0])
+    redirect = '?tiddlyweb_redirect=%s' % urllib.quote(redirect, safe='')
     return '%s/challenge/%s%s' % (server_base_url(environ), system, redirect)
 
 
